==> ruby-1.6.2-i386-mingw32.tar.gz: usr/local/lib/ruby/1.6/i386-mingw32/rbconfig.rb <==

module Config

  VERSION == "1.6.2" or
    raise "ruby lib version (1.6.2) doesn't match executable version (#{VERSION})"

# This file was created by configrb when ruby was built. Any changes
# made to this file will be lost the next time ruby is built.
  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-mingw32\Z', '')
  CONFIG["srcdir"] = "/home/pub/ruby/16/ruby-1.6.2"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby"
  CONFIG["EXEEXT"] = ".exe"
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["CFLAGS"] = "-DNT -D__MSVCRT__ -Os "
  CONFIG["CPPFLAGS"] = ""
  CONFIG["CXXFLAGS"] = ""
  CONFIG["FFLAGS"] = ""
  CONFIG["LDFLAGS"] = ""
  CONFIG["LIBS"] = "-lwsock32 -lmsvcrt "
  CONFIG["exec_prefix"] = "#{CONFIG[\"prefix\"]}"
  CONFIG["bindir"] = "#{CONFIG[\"exec_prefix\"]}/bin"
  CONFIG["sbindir"] = "#{CONFIG[\"exec_prefix\"]}/sbin"
  CONFIG["libexecdir"] = "#{CONFIG[\"exec_prefix\"]}/libexec"
  CONFIG["datadir"] = "#{CONFIG[\"prefix\"]}/share"
  CONFIG["sysconfdir"] = "#{CONFIG[\"prefix\"]}/etc"
  CONFIG["sharedstatedir"] = "#{CONFIG[\"prefix\"]}/com"
  CONFIG["localstatedir"] = "#{CONFIG[\"prefix\"]}/var"
  CONFIG["libdir"] = "#{CONFIG[\"exec_prefix\"]}/lib"
  CONFIG["includedir"] = "/usr/local/mingw/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "#{CONFIG[\"prefix\"]}/info"
  CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "6"
  CONFIG["TEENY"] = "2"
  CONFIG["host"] = "i686-pc-cygwin"
  CONFIG["host_alias"] = "i686-pc-cygwin"
  CONFIG["host_cpu"] = "i686"
  CONFIG["host_vendor"] = "pc"
  CONFIG["host_os"] = "cygwin"
  CONFIG["target"] = "i386-pc-mingw32"
  CONFIG["target_alias"] = "i386-mingw32"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "mingw32"
  CONFIG["build"] = "i586-pc-linux-gnu"
  CONFIG["build_alias"] = "i586-pc-linux-gnu"
  CONFIG["build_cpu"] = "i586"
  CONFIG["build_vendor"] = "pc"
  CONFIG["build_os"] = "linux-gnu"
  CONFIG["CC"] = "gcc -specs=specs.msvcrt -Zbmingw"
  CONFIG["CPP"] = "gcc -specs=specs.msvcrt -Zbmingw -E"
  CONFIG["YACC"] = "bison -y"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["NM"] = "nm"
  CONFIG["DLLWRAP"] = "dllwrap"
  CONFIG["AS"] = "as"
  CONFIG["DLLTOOL"] = "dlltool"
  CONFIG["WINDRES"] = "windres"
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["LIBOBJS"] = "memcmp.o crypt.o flock.o vsnprintf.o isinf.o isnan.o finite.o strtod.o win32.o"
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = ""
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-DIMPORT"
  CONFIG["LDSHARED"] = "dllwrap --target=mingw32 --as=as --dlltool-name=dlltool --driver-name=gcc -specs=specs.msvcrt -Zbmingw --export-all -s"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = "dll"
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/mingw -rfake"
  CONFIG["PREP"] = "fake.rb"
  CONFIG["LIBRUBY_LDSHARED"] = "dllwrap --target=mingw32 --as=as --dlltool-name=dlltool --driver-name=gcc -specs=specs.msvcrt -Zbmingw --export-all -s"
  CONFIG["LIBRUBY_DLDFLAGS"] = "--dllname=$@ --output-lib=$(LIBRUBY) --add-stdcall-alias --def=$(RUBYDEF)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
  CONFIG["RUBY_SO_NAME"] = "mingw32-$(RUBY_INSTALL_NAME)16"
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME)s.a"
  CONFIG["LIBRUBY_SO"] = "$(RUBY_SO_NAME).dll"
  CONFIG["LIBRUBY_ALIASES"] = ""
  CONFIG["LIBRUBY"] = "lib$(RUBY_SO_NAME).a"
  CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_SO_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = ""
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["arch"] = "i386-mingw32"
  CONFIG["sitedir"] = "#{CONFIG[\"prefix\"]}/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "--target=i386-mingw32 --host=i686-pc-cygwin --build=i586-pc-linux-gnu --includedir=/usr/local/mingw/include --enable-shared --cache=../config.cache-mingw --enable-tcltk_stubs --with-tcllib=tclstub83 --with-tklib=tkstub83 --with-opt-dir=/usr/local/mingw"
  CONFIG["compile_dir"] = "/home/pub/ruby/16/mingw"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        "#{Config::expand(CONFIG[\"#{key}\"])}"
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end

==> ruby-1.6.3-i386-mingw32.tar.gz: usr/local/lib/ruby/1.6/i386-mingw32/rbconfig.rb <==

module Config

  VERSION == "1.6.3" or
    raise "ruby lib version (1.6.3) doesn't match executable version (#{VERSION})"

# This file was created by configrb when ruby was built. Any changes
# made to this file will be lost the next time ruby is built.
  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-mingw32\Z', '')
  CONFIG["srcdir"] = "/home/pub/ruby/16/dist/ruby-1.6.3"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby"
  CONFIG["EXEEXT"] = ".exe"
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["CFLAGS"] = "-DNT -D__MSVCRT__ -Os -mwin32 "
  CONFIG["CPPFLAGS"] = ""
  CONFIG["CXXFLAGS"] = ""
  CONFIG["FFLAGS"] = ""
  CONFIG["LDFLAGS"] = ""
  CONFIG["LIBS"] = "-lwsock32 -lmsvcrt "
  CONFIG["exec_prefix"] = "#{CONFIG[\"prefix\"]}"
  CONFIG["bindir"] = "#{CONFIG[\"exec_prefix\"]}/bin"
  CONFIG["sbindir"] = "#{CONFIG[\"exec_prefix\"]}/sbin"
  CONFIG["libexecdir"] = "#{CONFIG[\"exec_prefix\"]}/libexec"
  CONFIG["datadir"] = "#{CONFIG[\"prefix\"]}/share"
  CONFIG["sysconfdir"] = "#{CONFIG[\"prefix\"]}/etc"
  CONFIG["sharedstatedir"] = "#{CONFIG[\"prefix\"]}/com"
  CONFIG["localstatedir"] = "#{CONFIG[\"prefix\"]}/var"
  CONFIG["libdir"] = "#{CONFIG[\"exec_prefix\"]}/lib"
  CONFIG["includedir"] = "/usr/local/mingw/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "#{CONFIG[\"prefix\"]}/info"
  CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "6"
  CONFIG["TEENY"] = "3"
  CONFIG["host"] = "i686-pc-cygwin"
  CONFIG["host_alias"] = "i686-pc-cygwin"
  CONFIG["host_cpu"] = "i686"
  CONFIG["host_vendor"] = "pc"
  CONFIG["host_os"] = "cygwin"
  CONFIG["target"] = "i386-pc-mingw32"
  CONFIG["target_alias"] = "i386-mingw32"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "mingw32"
  CONFIG["build"] = "i586-pc-linux-gnu"
  CONFIG["build_alias"] = "i586-pc-linux-gnu"
  CONFIG["build_cpu"] = "i586"
  CONFIG["build_vendor"] = "pc"
  CONFIG["build_os"] = "linux-gnu"
  CONFIG["CC"] = "gcc -bmingw"
  CONFIG["CPP"] = "gcc -bmingw -E"
  CONFIG["YACC"] = "bison -y"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["NM"] = "nm"
  CONFIG["DLLWRAP"] = "dllwrap"
  CONFIG["AS"] = "as"
  CONFIG["DLLTOOL"] = "dlltool"
  CONFIG["WINDRES"] = "windres"
  CONFIG["MWIN32"] = "-mwin32"
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["LIBOBJS"] = "memcmp.o crypt.o flock.o vsnprintf.o isinf.o isnan.o finite.o strtod.o win32.o"
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = ""
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-DIMPORT"
  CONFIG["LDSHARED"] = "dllwrap --target=mingw32 --as=as --dlltool-name=dlltool --driver-name=gcc -bmingw --export-all -s"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = "dll"
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/mingw -rfake"
  CONFIG["PREP"] = "fake.rb"
  CONFIG["LIBRUBY_LDSHARED"] = "dllwrap --target=mingw32 --as=as --dlltool-name=dlltool --driver-name=gcc -bmingw --export-all -s"
  CONFIG["LIBRUBY_DLDFLAGS"] = "--dllname=$@ --output-lib=$(LIBRUBY) --add-stdcall-alias --def=$(RUBYDEF)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
  CONFIG["RUBY_SO_NAME"] = "mingw32-$(RUBY_INSTALL_NAME)16"
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME)s.a"
  CONFIG["LIBRUBY_SO"] = "$(RUBY_SO_NAME).dll"
  CONFIG["LIBRUBY_ALIASES"] = ""
  CONFIG["LIBRUBY"] = "lib$(RUBY_SO_NAME).a"
  CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_SO_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = ""
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["arch"] = "i386-mingw32"
  CONFIG["sitedir"] = "#{CONFIG[\"prefix\"]}/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "--target=i386-mingw32 --host=i686-pc-cygwin --build=i586-pc-linux-gnu --includedir=/usr/local/mingw/include --enable-shared --cache=../config.cache-mingw --enable-tcltk_stubs --with-tcllib=tclstub83 --with-tklib=tkstub83 --with-opt-dir=/usr/local/mingw"
  CONFIG["compile_dir"] = "/home/pub/ruby/16/dist/mingw"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        "#{Config::expand(CONFIG[\"#{key}\"])}"
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end
